import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

public class ComparableDemo {

	public static void main(String[] args) {
		
		Poker[] cards = {new Poker(Suit.Heart, Rank.three),
				         new Poker(Suit.Spade, Rank.two),
				         new Poker(Suit.Diamond, Rank.two),
				         new Poker(Suit.Club, Rank.A)};
		
		Arrays.sort(cards);
		
		// sort in descending order by anonymous class
		Arrays.sort(cards, new Comparator<Poker>() {
			
			@Override
			public int compare(Poker c1, Poker c2) {
			
				int r1 = c1.getRank().ordinal();
				int r2 = c2.getRank().ordinal();
				
				int s1 = c1.getSuit().ordinal();
				int s2 = c2.getSuit().ordinal();
	
				return r1 - r2 != 0 ? r2 - r1 : s2 - s1;
			}
			
		});
		
		for (Poker card: cards) {
			System.out.println(card);
		}
		
		// sort in descending order by anonymous function
		/*
		Arrays.sort(cards, (c1, c2) -> {
			
			int r1 = c1.getRank().ordinal();
			int r2 = c2.getRank().ordinal();
			
			int s1 = c1.getSuit().ordinal();
			int s2 = c2.getSuit().ordinal();

			return r1 - r2 != 0 ? r1 - r2 : s1 - s2;
			
		});
		*/
		
		
		// preview: Stream API
		/*
		List<Poker> cards2 = Arrays.asList(cards);
		Collections.sort(cards2);
		cards2.forEach(System.out::println);
		*/

	}

}
